@@ -101,7 +101,7 @@ of this source is accessible and properly loaded."
 
 (defcustom helm-buffers-end-truncated-string
   ;; `truncate-string-ellipsis', the function is not available in 27.1
-  ;; See issue#2673. 
+  ;; See issue#2673.
   (if (char-displayable-p ?…) "…" "...")
   "The string to display at end of truncated buffer names."
   :type 'string)
@@ -962,7 +962,7 @@ If REGEXP-FLAG is given use `query-replace-regexp'."
   'helm-grep-buffers)
 
 (helm-make-command-from-action helm-buffer-run-zgrep
-  "Run Grep action from `helm-source-buffers-list'."
+  "Run Zgrep action from `helm-source-buffers-list'."
   'helm-zgrep-buffers)
 
 (helm-make-command-from-action helm-buffer-run-query-replace-regexp
@@ -1041,8 +1041,14 @@ vertically."
       (helm-delete-current-selection))))
 
 (defun helm-buffers--quote-truncated-buffer (buffer)
+  "Quote the truncated buffer-name of BUFFER.
+buffer-name is truncated according to `helm-buffer-max-length' minus the length
+of icon if one."
   (let ((bufname (and (bufferp buffer)
-                      (buffer-name buffer))))
+                      (buffer-name buffer)))
+        (maxlen (if helm-buffers-show-icons
+                    (- helm-buffer-max-length 2)
+                  helm-buffer-max-length)))
     (when (and bufname
                (file-remote-p (with-current-buffer bufname
                                 default-directory)))
@@ -1051,32 +1057,37 @@ vertically."
       (regexp-quote
        (if (and helm-buffer-max-length
                 helm-buffer-details-flag)
-           (helm-substring-by-width
-            bufname helm-buffer-max-length
-            "")
+           (helm-substring-by-width bufname maxlen "")
          bufname)))))
 
 (defun helm-buffers-persistent-kill (_buffer)
-  (let ((marked (helm-marked-candidates))
-        (sel (helm-get-selection))
-        (msg "Buffer `%s' modified, please save it before kill"))
-    (unwind-protect
-         (cl-loop for b in marked
-                  do (if (and (buffer-file-name b) (buffer-modified-p b))
-                         (message msg (buffer-name b))
-                       ;; We need to preselect each marked because
-                       ;; helm-buffers-persistent-kill-1 is deleting
-                       ;; current selection.
-                       (helm-preselect
-                        (format "^%s"
-                                (helm-buffers--quote-truncated-buffer b)))
-                       (helm-buffers-persistent-kill-1 b)
-                       (message nil)
-                       (helm--remove-marked-and-update-mode-line b)))
-      (with-helm-buffer
+  (let* ((marked (helm-marked-candidates))
+         (msg "Buffer `%s' modified, please save it before kill")
+         ;; After marking, selection should be after the last marked unless user
+         ;; has not moved, if deleting current, use current selection after
+         ;; having deleted.
+         (sel (and (cdr marked) (helm-get-selection))))
+    (with-helm-buffer
+      (unwind-protect
+           (dolist (b marked)
+             (if (and (buffer-file-name b) (buffer-modified-p b))
+                 (progn (message msg (buffer-name b)) (sit-for 1))
+               ;; We need to preselect each marked because
+               ;; helm-buffers-persistent-kill-1 is deleting
+               ;; current selection.
+               (helm-preselect
+                (format "^[[:multibyte:] ]*%s"
+                        (helm-buffers--quote-truncated-buffer b)))
+               (helm-buffers-persistent-kill-1 b)
+               (helm--remove-marked-and-update-mode-line b)))
         (setq helm-marked-candidates nil
               helm-visible-mark-overlays nil))
-      (helm-force-update (helm-buffers--quote-truncated-buffer sel)))))
+      (helm-force-update (format "^[[:multibyte:] ]*%s"
+                                 (helm-buffers--quote-truncated-buffer
+                                  ;; Ensure user has not moved selection on one
+                                  ;; of marked.
+                                  (or (and (buffer-live-p sel) sel)
+                                      (helm-get-selection))))))))
 
 (defun helm-buffers-list-persistent-action (candidate)
   (let ((current (window-buffer helm-persistent-action-display-window)))
