@@ -415,22 +415,26 @@ the same time to variable and a function."
            for sym = (if (string-match "\\`:[[:alpha:]]+:\\'" c)
                          c (intern-soft c))
            for annot = (helm-acase sym
-                         ((guard* (stringp it))      "<reg> ")
-                         ((guard* (commandp it))     "<com> ")
-                         ((guard* (class-p it))      "<cla> ")
-                         ((guard* (cl-generic-p it)) "<gen> ")
-                         ((guard* (fboundp it))      "<fun> ")
-                         ((guard* (keywordp it))     "<kwd> ")
-                         ((guard* (boundp it))       "<var> ")
-                         ((guard* (facep it))        "<fac> ")
-                         ((guard* (helm-group-p it)) "<grp> ")
+                         ((guard* (stringp it))
+                          (propertize "<reg> " 'face 'font-lock-regexp-face))
+                         ((guard* (commandp it))
+                          (propertize "<com> " 'face 'font-lock-function-name-face))
+                         ((guard* (class-p it))
+                          (propertize "<cla> " 'face 'font-lock-type-face))
+                         ((guard* (cl-generic-p it))
+                          (propertize "<gen> " 'face 'font-lock-function-name-face))
+                         ((guard* (fboundp it))
+                          (propertize "<fun> " 'face 'font-lock-function-name-face))
+                         ((guard* (keywordp it))
+                          (propertize "<kwd> " 'face 'font-lock-keyword-face))
+                         ((guard* (boundp it))
+                          (propertize "<var> " 'face 'font-lock-variable-name-face))
+                         ((guard* (facep it))
+                          (propertize "<fac> " 'face 'font-lock-variable-name-face))
+                         ((guard* (helm-group-p it))
+                          (propertize "<grp> " 'face 'font-lock-type-face))
                          (t                         "      "))
-           collect (cons (concat (helm-aand
-                                  (propertize
-                                   annot 'face 'helm-completions-annotations)
-                                  (propertize " " 'display it))
-                                 c)
-                         c)
+           collect (cons (concat (propertize " " 'display annot) c) c)
            into lst
            finally return (sort lst #'helm-generic-sort-fn)))
 
@@ -628,9 +632,9 @@ is only used to test DEFAULT."
                    . ,(lambda (candidate)
                         (let ((sym (helm-symbolify candidate)))
                           (set sym standard-value)))))))
-            '(("Customize variable" .
-               (lambda (candidate)
-                 (customize-option (helm-symbolify candidate)))))))
+            `(("Customize variable"
+               . ,(lambda (candidate)
+                    (customize-option (helm-symbolify candidate)))))))
           ((and val (with-helm-current-buffer (ring-p (symbol-value sym))))
            (append actions
                    '(("Clean ring" . helm-apropos-clean-ring))))
