@@ -298,7 +298,7 @@ value used in `helm-grep-ag-command'.
 
 Note also that by default the \"--\" option is always used, you don't
 need to add it here.
- 
+
 You probably don't need to use this unless you know what you are
 doing."
   :type '(repeat string))
@@ -830,6 +830,7 @@ If N is positive go forward otherwise go backward."
   (interactive)
   (with-helm-window
     (helm-goto-next-or-prec-file 1)))
+(put 'helm-goto-next-file 'helm-only t)
 
 (helm-make-command-from-action helm-grep-run-default-action
   "Run grep default action from `helm-do-grep-1'."
@@ -930,11 +931,11 @@ RESET non-nil means rewind to the first match.
 This is the `next-error-function' for `helm-grep-mode'."
   (interactive "p")
   (goto-char (cond (reset (point-min))
-		   ((and (< argp 0) helm-current-error)
+                  ((and (< argp 0) helm-current-error)
                     (line-beginning-position))
-		   ((and (> argp 0) helm-current-error)
+                  ((and (> argp 0) helm-current-error)
                     (line-end-position))
-		   ((point))))
+                  ((point))))
   (let ((fun (if (> argp 0)
                  #'next-single-property-change
                #'previous-single-property-change)))
@@ -1040,10 +1041,12 @@ Special commands:
 (defun helm-gm-next-file ()
   (interactive)
   (helm-goto-next-or-prec-file 1))
+(put 'helm-gm-next-file 'helm-only t)
 
 (defun helm-gm-precedent-file ()
   (interactive)
   (helm-goto-next-or-prec-file -1))
+(put 'helm-gm-precedent-file 'helm-only t)
 
 (defun helm-grep-mode-jump ()
   (interactive)
@@ -1643,7 +1646,7 @@ returns if available with current AG version."
         (cmd-line (helm-grep-ag-prepare-cmd-line
                    ;; NOTE Encode directory name and pattern,
                    ;; or it may not work with Chinese and maybe other non-utf8
-                   ;; characters on MSWindows systems issue#2677 and issue#2678. 
+                   ;; characters on MSWindows systems issue#2677 and issue#2678.
                    (encode-coding-string helm-pattern locale-coding-system)
                    (or (file-remote-p directory 'localname)
                        (encode-coding-string directory locale-coding-system))
@@ -1706,7 +1709,9 @@ returns if available with current AG version."
 (defun helm-grep-ag-search-results (_candidate)
   "Launch a new helm session on the current results.
 Allow narrowing the grep ag results to a specific file or pattern without
-continuing calling grep ag."
+continuing calling grep ag, i.e. once called, what you type in minibuffer will be
+searched with helm match functions in all the candidates found previously by
+grep ag."
   (with-helm-buffer
     (let* ((src        (helm-get-current-source))
            (candidates (nthcdr 1 (split-string
