@@ -1,8 +1,8 @@
 ;;; helm-lib.el --- Helm routines. -*- lexical-binding: t -*-
 
-;; Copyright (C) 2015 ~ 2020  Thierry Volpiatto
+;; Copyright (C) 2015 ~ 2025  Thierry Volpiatto
 
-;; Author: Thierry Volpiatto 
+;; Author: Thierry Volpiatto
 ;; URL: http://github.com/emacs-helm/helm
 
 ;; This program is free software; you can redistribute it and/or modify
@@ -114,14 +114,10 @@ convenient to use a simple boolean value here."
 (defun helm-ff--setup-boring-regex (var val)
   (set var val)
   (setq helm-ff--boring-regexp
-          (cl-loop with last = (car (last val))
-                   for r in (butlast val)
-                   if (string-match "\\$\\'" r)
-                   concat (concat r "\\|") into result
-                   else concat (concat r "$\\|") into result
-                   finally return
-                   (concat result last
-                           (if (string-match "\\$\\'" last) "" "$")))))
+        (cl-loop for r on val
+                 if (cdr r)
+                 concat (concat (car r) "\\|")
+                 else concat (car r))))
 
 (defcustom helm-boring-file-regexp-list
   (mapcar (lambda (f)
@@ -129,13 +125,15 @@ convenient to use a simple boolean value here."
               (if (string-match-p "[^/]$" f)
                   ;; files: e.g .o => \\.o$
                   (concat rgx "$")
-                ;; directories: e.g .git/ => \.git\\(/\\|$\\)
-                (concat (substring rgx 0 -1) "\\(/\\|$\\)"))))
+                ;; To not ignore files with same prefix as directory names
+                ;; (bug#2009) use e.g. .git/ => \.git\?$.
+                ;; See also PR in bug#2012.
+                (concat rgx "?$"))))
           completion-ignored-extensions)
   "A list of regexps matching boring files.
 
 This list is build by default on `completion-ignored-extensions'.
-The directory names should end with \"/?\" e.g. \"\\.git/?\" and
+The directory names should end with \"/?$\" e.g. \"\\.git/?$\" and
 the file names should end with \"$\" e.g. \"\\.o$\".
 
 These regexps may be used to match the entire path, not just the
@@ -161,7 +159,10 @@ the customize functions e.g. `customize-set-variable' and NOT
 
 (defcustom helm-current-directory-alist
   '((dired-mode . dired-current-directory)
-    (mu4e-main-mode . mu4e-root-maildir))
+    (mu4e-main-mode . mu4e-root-maildir)
+    (gnus-group-mode . gnus-directory)
+    (gnus-summary-mode . gnus-directory)
+    (gnus-article-mode . gnus-directory))
   "Tell `helm-current-directory' what to use according to `major-mode'.
 Each element of alist is (MAJOR-MODE . SYMBOL) where SYMBOL is either a variable
 or a function."
@@ -323,7 +324,7 @@ the leading `-' char."
         (unless package--initialized (package-initialize 'no-activate))
         (or (cadr (assq pkg-name package-alist))
             (cadr (assq pkg-name package-archive-contents))))
-      
+
       (defun package-upgrade (name)
         "Upgrade package NAME if a newer version exists."
         (let* ((package (if (symbolp name)
@@ -351,17 +352,7 @@ object."
           (dolist (elc (directory-files-recursively
                         (package-desc-dir pkg-desc) "\\.elc\\'"))
             (delete-file elc))
-          (package--compile pkg-desc)))
-
-      (defun package--dependencies (pkg)
-        "Return a list of all dependencies PKG has.
-This is done recursively."
-        ;; Can we have circular dependencies?  Assume "nope".
-        (let* ((desc (cadr (assq pkg package-archive-contents)))
-               (deps (and desc (mapcar #'car (package-desc-reqs desc)))))
-          (when deps
-            (delete-dups
-             (apply #'nconc deps (mapcar #'package--dependencies deps)))))))))
+          (package--compile pkg-desc))))))
 
 ;;; Provide `help--symbol-class' not available in emacs-27
 ;;
@@ -399,10 +390,10 @@ This is done recursively."
         object
       (let ((vec (string-to-vector object)))
         (unless (multibyte-string-p object)
-	  (dotimes (i (length vec))
-	    (let ((k (aref vec i)))
-	      (when (> k 127)
-	        (setf (aref vec i) (+ k ?\M-\C-@ -128))))))
+          (dotimes (i (length vec))
+            (let ((k (aref vec i)))
+              (when (> k 127)
+                (setf (aref vec i) (+ k ?\M-\C-@ -128))))))
         vec))))
 
 (defun helm-proper-list-p (obj)
@@ -2033,7 +2024,7 @@ Directories expansion is not supported."
       (goto-char (point-min))
       (when (re-search-forward "^;;;?\\(.*\\) ---? \\(.*\\)" (pos-eol) t)
         (setq desc (match-string-no-properties 2)))
-      (if (or (null desc) (string= "" desc))
+      (if (or (null desc) (string= "" desc) (string-match "\\`-\\*-" desc))
           "Not documented"
         (car (split-string desc "-\\*-" nil "[ \t\n\r-]+"))))))
 
