@@ -1,4 +1,4 @@
-;;; helm-packages.el --- helm interface to manage packages  -*- lexical-binding: t; -*- 
+;;; helm-packages.el --- helm interface to manage packages  -*- lexical-binding: t; -*-
 
 ;; Copyright (C) 2012 ~ 2025 Thierry Volpiatto
 
@@ -37,9 +37,9 @@
    (find-file-target :initform #'helm-packages-quit-an-find-file)
    (filtered-candidate-transformer
     :initform
-    '(helm-packages-transformer
-      (lambda (candidates _source)
-        (sort candidates #'helm-generic-sort-fn))))
+    `(helm-packages-transformer
+      ,(lambda (candidates _source)
+         (sort candidates #'helm-generic-sort-fn))))
    (update :initform #'helm-packages--refresh-contents))
   "A class to define `helm-packages' sources.")
 
@@ -163,13 +163,22 @@ as dependencies."
             (async-package-do-action 'install mkd error-file)
           (helm-packages-install--sync mkd))))))
 
+(defun helm-packages--get-deps (pkg)
+  "Recursively find PKG dependencies."
+  (let ((desc (cadr (assq pkg package-archive-contents))))
+    (when desc
+      (cl-loop for req in (package-desc-reqs desc) ; (foo (1 2 3))
+               for sym = (car req)
+               nconc (cons sym (helm-packages--get-deps sym)) into pkgs
+               finally return (helm-fast-remove-dups pkgs)))))
+
 (defun helm-packages-isolate-1 (packages &optional _ignore)
     "Start an Emacs with only PACKAGES loaded.
 Arg PACKAGES is a list of strings."
     (let* ((name (concat "package-isolate-" (mapconcat #'identity packages "_")))
            (deps (cl-loop for p in packages
                           for sym = (intern p)
-                          nconc (package--dependencies sym))))
+                          nconc (helm-packages--get-deps sym))))
       (apply #'start-process name nil
              (list (expand-file-name invocation-name invocation-directory)
                    "-Q" "--debug-init"
@@ -277,7 +286,7 @@ Arg PACKAGES is a list of strings."
 (defun helm-finder--list-matches (key)
   (let* ((id (intern key))
          (built-in (gethash id finder-keywords-hash))
-	 (exts (cl-loop for p in package-archive-contents
+    (exts (cl-loop for p in package-archive-contents
                         for sym = (car p)
                         when (package--has-keyword-p
                               (package-get-descriptor sym)
@@ -298,9 +307,9 @@ Arg PACKAGES is a list of strings."
                         'global (helm-fast-remove-dups
                                  (helm-finder--list-matches candidate))))
             :filtered-candidate-transformer
-            (list #'helm-packages-transformer
-                  (lambda (candidates _source)
-                    (sort candidates #'helm-generic-sort-fn)))
+            `(helm-packages-transformer
+              ,(lambda (candidates _source)
+                 (sort candidates #'helm-generic-sort-fn)))
             :action-transformer
             (lambda (actions candidate)
               (if (package-installed-p candidate)
@@ -322,7 +331,7 @@ Arg PACKAGES is a list of strings."
                                    when (not (assq sym package-alist))
                                    nconc (list (list sym (package--from-builtin
                                                           (cons sym vec))))))
-                package-alist))) 
+                package-alist)))
     (cl-loop for (sym desc) in pkgs
              for pkg = (assq sym package-archive-contents)
              for cversion = (and pkg (package-desc-version desc))
