@@ -1053,8 +1053,9 @@ Assume regexp is a pcre based regexp."
 (defvar helm--show-help-echo-timer nil)
 (defvar helm--maybe-show-help-echo-overlay nil)
 (defface helm-tooltip
-  '((t :background "Goldenrod"
-       :foreground "black"))
+  '((((type tty pc))
+     :background "yellow" :foreground "black")
+    (t :background "Goldenrod" :foreground "black"))
   "Face used by `helm-tooltip-show'."
   :group 'helm-grep-faces)
 
